package com.zcloud.modules.kangzai.controller;

import com.zcloud.common.annotation.SysLog;
import com.zcloud.common.utils.PageUtils;
import com.zcloud.common.utils.R;
import com.zcloud.common.utils.Tools;
import com.zcloud.modules.kangzai.entity.BusEmergencyStorageEntity;
import com.zcloud.modules.kangzai.service.BusEmergencyStorageService;
import com.zcloud.modules.sys.controller.AbstractController;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;

import java.util.Map;

/**
 * @Author fangjiakai
 * @Desc 应急储备库信息表(BusEmergencyStorage)表控制层
 * @Date 2025-06-09 10:14:58
 */
@Api(tags = "应急储备库信息表")
@RestController
@RequestMapping("busEmergencyStorage")
public class BusEmergencyStorageController extends AbstractController {

    @Autowired
    private BusEmergencyStorageService busEmergencyStorageService;

    @ApiOperation("应急储备库信息表-新增数据")
    @SysLog("应急储备库信息表-新增数据")
    @PostMapping("/save")
    public R insert(@RequestBody BusEmergencyStorageEntity param) {
        param.setCreator(getUserId());
        param.setOperator(getUserId());
        busEmergencyStorageService.save(param);

        return R.ok();
    }

    @ApiOperation("应急储备库信息表-编辑数据")
    @SysLog("应急储备库信息表-编辑数据")
    @PostMapping("/update")
    public R update(@RequestBody BusEmergencyStorageEntity param) {
        param.setOperator(getUserId());
        busEmergencyStorageService.updateById(param);

        return R.ok();
    }


    @ApiOperation("应急储备库信息表-删除数据")
    @SysLog("应急储备库信息表-删除数据")
    @PostMapping("/delete")
    public R delete(@RequestBody BusEmergencyStorageEntity param) {
        busEmergencyStorageService.delete(param.getEmergencyStorageId(), getUserId());
        return R.ok();
    }

    @ApiOperation("应急储备库信息表-分页查询")
    @SysLog("应急储备库信息表-分页查询")
    @PostMapping("/listPage")
    public R listPage(@RequestBody Map<String, Object> params) {
        PageUtils page = busEmergencyStorageService.listPage(params);

        return R.ok().put("page", page);
    }


    @ApiOperation("应急储备库信息表-根据ID查详情")
    @SysLog("应急储备库信息表-根据ID查详情")
    @PostMapping("/info")
    public R info(@RequestBody BusEmergencyStorageEntity param) {
        BusEmergencyStorageEntity busEmergencyStorage = busEmergencyStorageService.getById(param.getEmergencyStorageId());
        return R.ok().put("busEmergencyStorage", busEmergencyStorage);
    }

    @PostMapping("/list")
    public R list() {
        return R.ok().put("list", busEmergencyStorageService.queryByFlexibleParams("is_delete", "0"));
    }

}
