package com.zcloud.modules.kangzai.controller;

import com.zcloud.common.annotation.SysLog;
import com.zcloud.common.utils.PageUtils;
import com.zcloud.common.utils.R;
import com.zcloud.common.utils.Tools;
import com.zcloud.modules.kangzai.entity.BusReservoirBasicEntity;
import com.zcloud.modules.kangzai.service.BusReservoirBasicService;
import com.zcloud.modules.sys.controller.AbstractController;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;

import java.util.Map;

/**
 * @Author fangjiakai
 * @Desc 水库基本信息表(BusReservoirBasic)表控制层
 * @Date 2025-06-09 10:14:59
 */
@Api(tags = "水库基本信息表")
@RestController
@RequestMapping("busReservoirBasic")
public class BusReservoirBasicController extends AbstractController {

    @Autowired
    private BusReservoirBasicService busReservoirBasicService;

    @ApiOperation("水库基本信息表-新增数据")
    @SysLog("水库基本信息表-新增数据")
    @PostMapping("/save")
    public R insert(@RequestBody BusReservoirBasicEntity param) {
        param.setCreator(getUserId());
        param.setOperator(getUserId());
        busReservoirBasicService.save(param);

        return R.ok();
    }

    @ApiOperation("水库基本信息表-编辑数据")
    @SysLog("水库基本信息表-编辑数据")
    @PostMapping("/update")
    public R update(@RequestBody BusReservoirBasicEntity param) {
        param.setOperator(getUserId());
        busReservoirBasicService.updateById(param);

        return R.ok();
    }


    @ApiOperation("水库基本信息表-删除数据")
    @SysLog("水库基本信息表-删除数据")
    @PostMapping("/delete")
    public R delete(@RequestBody BusReservoirBasicEntity param) {
        busReservoirBasicService.delete(param.getReservoirBasicId(), getUserId());
        return R.ok();
    }

    @ApiOperation("水库基本信息表-分页查询")
    @SysLog("水库基本信息表-分页查询")
    @PostMapping("/listPage")
    public R listPage(@RequestBody Map<String, Object> params) {
        PageUtils page = busReservoirBasicService.listPage(params);

        return R.ok().put("page", page);
    }


    @ApiOperation("水库基本信息表-根据ID查详情")
    @SysLog("水库基本信息表-根据ID查详情")
    @PostMapping("/info")
    public R info(@RequestBody BusReservoirBasicEntity param) {
        BusReservoirBasicEntity busReservoirBasic = busReservoirBasicService.getById(param.getReservoirBasicId());
        return R.ok().put("busReservoirBasic", busReservoirBasic);
    }

    @PostMapping("/list")
    public R list() {
        return R.ok().put("list", busReservoirBasicService.queryByFlexibleParams("is_delete", "0"));
    }

}
