package com.zcloud.modules.kangzai.controller;

import com.zcloud.common.annotation.SysLog;
import com.zcloud.common.utils.PageUtils;
import com.zcloud.common.utils.R;
import com.zcloud.common.utils.Tools;
import com.zcloud.modules.kangzai.entity.BusRiverEntity;
import com.zcloud.modules.kangzai.service.BusRiverService;
import com.zcloud.modules.sys.controller.AbstractController;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;

import java.util.Map;

/**
 * @Author fangjiakai
 * @Desc 河流基础信息表(BusRiver)表控制层
 * @Date 2025-06-09 09:44:23
 */
@Api(tags = "河流基础信息表")
@RestController
@RequestMapping("busRiver")
public class BusRiverController extends AbstractController {

    @Autowired
    private BusRiverService busRiverService;

    @ApiOperation("河流基础信息表-新增数据")
    @SysLog("河流基础信息表-新增数据")
    @PostMapping("/save")
    public R insert(@RequestBody BusRiverEntity param) {
        param.setCreator(getUserId());
        param.setOperator(getUserId());
        busRiverService.save(param);

        return R.ok();
    }

    @ApiOperation("河流基础信息表-编辑数据")
    @SysLog("河流基础信息表-编辑数据")
    @PostMapping("/update")
    public R update(@RequestBody BusRiverEntity param) {
        param.setOperator(getUserId());
        busRiverService.updateById(param);

        return R.ok();
    }


    @ApiOperation("河流基础信息表-删除数据")
    @SysLog("河流基础信息表-删除数据")
    @PostMapping("/delete")
    public R delete(@RequestBody BusRiverEntity param) {
        busRiverService.delete(param.getRiverId(), getUserId());
        return R.ok();
    }

    @ApiOperation("河流基础信息表-分页查询")
    @SysLog("河流基础信息表-分页查询")
    @PostMapping("/listPage")
    public R listPage(@RequestBody Map<String, Object> params) {
        PageUtils page = busRiverService.listPage(params);

        return R.ok().put("page", page);
    }


    @ApiOperation("河流基础信息表-根据ID查详情")
    @SysLog("河流基础信息表-根据ID查详情")
    @PostMapping("/info")
    public R info(@RequestBody BusRiverEntity param) {
        BusRiverEntity busRiver = busRiverService.getById(param.getRiverId());
        return R.ok().put("busRiver", busRiver);
    }

    @PostMapping("/list")
    public R list() {
        return R.ok().put("list", busRiverService.queryByFlexibleParams("is_delete", "0"));
    }
}
