package com.zcloud.modules.kangzai.controller;

import com.zcloud.common.annotation.SysLog;
import com.zcloud.common.utils.PageUtils;
import com.zcloud.common.utils.R;
import com.zcloud.modules.kangzai.entity.BusRiverPointEntity;
import com.zcloud.modules.kangzai.service.BusRiverPointService;
import com.zcloud.modules.sys.controller.AbstractController;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import java.util.Map;

/**
 * @Author fangjiakai
 * @Desc 河流经纬度坐标点信息表(BusRiverPoint)表控制层
 * @Date 2025-06-09 09:50:37
 */
@Api(tags = "河流经纬度坐标点信息表")
@RestController
@RequestMapping("busRiverPoint")
public class BusRiverPointController extends AbstractController {

    @Autowired
    private BusRiverPointService busRiverPointService;

    @ApiOperation("河流经纬度坐标点信息表-新增数据")
    @SysLog("河流经纬度坐标点信息表-新增数据")
    @PostMapping("/save")
    public R insert(@RequestBody BusRiverPointEntity param) {
        busRiverPointService.save(param);

        return R.ok();
    }

    @ApiOperation("河流经纬度坐标点信息表-编辑数据")
    @SysLog("河流经纬度坐标点信息表-编辑数据")
    @PostMapping("/update")
    public R update(@RequestBody BusRiverPointEntity param) {
        busRiverPointService.updateById(param);

        return R.ok();
    }


    @ApiOperation("河流经纬度坐标点信息表-删除数据")
    @SysLog("河流经纬度坐标点信息表-删除数据")
    @PostMapping("/delete")
    public R delete(@RequestBody BusRiverPointEntity param) {
        busRiverPointService.delete(param.getRiverPointId(),getUserId());
        return R.ok();
    }

    @ApiOperation("河流经纬度坐标点信息表-分页查询")
    @SysLog("河流经纬度坐标点信息表-分页查询")
    @PostMapping("/listPage")
    public R listPage(@RequestBody Map<String, Object> params) {
        PageUtils page = busRiverPointService.listPage(params);

		return R.ok().put("page", page);
    }


    @ApiOperation("河流经纬度坐标点信息表-根据ID查详情")
    @SysLog("河流经纬度坐标点信息表-根据ID查详情")
    @PostMapping("/info")
    public R info(@RequestBody BusRiverPointEntity param) {
        BusRiverPointEntity busRiverPoint = busRiverPointService.getById(param.getRiverPointId());
        return R.ok().put("busRiverPoint", busRiverPoint);
    }

    @PostMapping("/list")
    public R list() {
        return R.ok().put("list", busRiverPointService.queryByFlexibleParams("is_delete", "0"));
    }
}
