package com.zcloud.modules.kangzai.controller;

import com.zcloud.common.annotation.SysLog;
import com.zcloud.common.utils.PageUtils;
import com.zcloud.common.utils.R;
import com.zcloud.common.utils.Tools;
import com.zcloud.modules.kangzai.entity.BusUrbanFloodPointEntity;
import com.zcloud.modules.kangzai.service.BusUrbanFloodPointService;
import com.zcloud.modules.sys.controller.AbstractController;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;

import java.util.Map;

/**
 * @Author fangjiakai
 * @Desc 城市防涝点详情表(BusUrbanFloodPoint)表控制层
 * @Date 2025-06-09 10:15:00
 */
@Api(tags = "城市防涝点详情表")
@RestController
@RequestMapping("busUrbanFloodPoint")
public class BusUrbanFloodPointController extends AbstractController {

    @Autowired
    private BusUrbanFloodPointService busUrbanFloodPointService;

    @ApiOperation("城市防涝点详情表-新增数据")
    @SysLog("城市防涝点详情表-新增数据")
    @PostMapping("/save")
    public R insert(@RequestBody BusUrbanFloodPointEntity param) {
        param.setCreator(getUserId());
        param.setOperator(getUserId());
        busUrbanFloodPointService.save(param);

        return R.ok();
    }

    @ApiOperation("城市防涝点详情表-编辑数据")
    @SysLog("城市防涝点详情表-编辑数据")
    @PostMapping("/update")
    public R update(@RequestBody BusUrbanFloodPointEntity param) {
        param.setOperator(getUserId());
        busUrbanFloodPointService.updateById(param);

        return R.ok();
    }


    @ApiOperation("城市防涝点详情表-删除数据")
    @SysLog("城市防涝点详情表-删除数据")
    @PostMapping("/delete")
    public R delete(@RequestBody BusUrbanFloodPointEntity param) {
        busUrbanFloodPointService.delete(param.getUrbanFloodPointId(), getUserId());
        return R.ok();
    }

    @ApiOperation("城市防涝点详情表-分页查询")
    @SysLog("城市防涝点详情表-分页查询")
    @PostMapping("/listPage")
    public R listPage(@RequestBody Map<String, Object> params) {
        PageUtils page = busUrbanFloodPointService.listPage(params);

        return R.ok().put("page", page);
    }


    @ApiOperation("城市防涝点详情表-根据ID查详情")
    @SysLog("城市防涝点详情表-根据ID查详情")
    @PostMapping("/info")
    public R info(@RequestBody BusUrbanFloodPointEntity param) {
        BusUrbanFloodPointEntity busUrbanFloodPoint = busUrbanFloodPointService.getById(param.getUrbanFloodPointId());
        return R.ok().put("busUrbanFloodPoint", busUrbanFloodPoint);
    }

    @PostMapping("/list")
    public R list() {
        return R.ok().put("list", busUrbanFloodPointService.queryByFlexibleParams("is_delete", "0"));
    }
}
