

package com.zcloud.modules.sys.service;

import com.baomidou.mybatisplus.extension.service.IService;
import com.zcloud.common.utils.PageUtils;
import com.zcloud.common.utils.R;
import com.zcloud.modules.sys.entity.SysUserEntity;
import org.springframework.web.multipart.MultipartFile;

import java.io.IOException;
import java.util.List;
import java.util.Map;


/**
 * 系统用户
 *
 *
 */
public interface SysUserService extends IService<SysUserEntity> {

	PageUtils queryPage(Map<String, Object> params);

	SysUserEntity queryById(String userId);

	/**
	 * 查询用户的所有权限
	 * @param userId  用户ID
	 */
	List<String> queryAllPerms(String userId);

	/**
	 * 查询用户的所有菜单ID
	 */
	List<String> queryAllMenuId(String userId);

	/**
	 * 根据用户名，查询系统用户
	 */
	SysUserEntity queryByUserName(String username);

	/**
	 * 保存用户
	 */
	R saveUser(SysUserEntity user,MultipartFile file) throws IOException;

	/**
	 * 修改用户
	 */
	void update(SysUserEntity user);

	R updateSysUserInfo(SysUserEntity user,MultipartFile file) throws IOException;

	/**
	 * 删除用户
	 */
	void deleteBatch(String[] userIds);

	/**
	 * 修改密码
	 * @param userId       用户ID
	 * @param password     原密码
	 * @param newPassword  新密码
	 */
	boolean updatePassword(String userId, String password, String newPassword);

	/**
	 * 获取全部用户 （不分页）
	 */
	List<SysUserEntity> listAll(Map<String, Object> params);

	/**
	 * 下拉用户列表（不分页）
	 */
	List<SysUserEntity> listForSelect(Map<String, Object> params);

	/**
	 * 根据手机号查询用户
	 */
	SysUserEntity findByMobile(String phone);

	/**
	 * 根据手机号修改openid
	 */
    void editOpenid(String phone, String openid);
}
